"""

  """

import importlib

import src.giteasy as sgi


importlib.reload(sgi)

from src.giteasy.repo import get_github_token_json_fp
from src.giteasy.repo import Repo
from src.giteasy.github import ret_pygithub_repo_obj , get_all_fps_in_repo


## test get_github_token_pathes()
fp = get_github_token_json_fp()
print(fp)

## clone a public repo
u = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
repo = Repo(u)
repo.overwriting_clone()

##
repo.rmdir()

## clone a private repo
ur = 'https://github.com/imahdimir/test-private'
rp = Repo(ur)
rp.overwriting_clone()

##
rp.commit_and_push('test commit')

##
rp.rmdir()

##
rp = 'https://github.com/imahdimir/Codal-monthly-sales-htmls'
ob = ret_pygithub_repo_obj(rp)
x = get_all_fps_in_repo(rp)
print(x)
print(len(x))

##
rp = 'https://github.com/imahdimir/td-u-d0-FirmTicker-MonthlySales'
ob = ret_pygithub_repo_obj(rp)
find_sha_of_a_file_in_github_repo(rp , 'a.prq')

##
rp = 'https://github.com/imahdimir/td-u-d0-FirmTicker-MonthlySales'
fp0 = '/Users/mahdi/Dropbox/1-git-dirs/PyCharm/u-d0-FirmTicker-MonthlySales/link-htmls/302345.html'
fp1 = '/Users/mahdi/Dropbox/1-git-dirs/PyCharm/u-d0-FirmTicker-MonthlySales/link-htmls/302229.html'
fps = [fp0 , fp1]
asyncio.run(add_xor_overwrite_txt_based_files_2_github_repo_async(fps , rp))

##
rp = 'https://github.com/imahdimir/td-u-d0-FirmTicker-MonthlySales'
di = '/Users/mahdi/Dropbox/1-git-dirs/PyCharm/u-d0-FirmTicker-MonthlySales/link-htmls'
fu = add_txt_based_files_fr_dir_to_github_repo_async
asyncio.run(fu(di , 'html' , rp))

##
rp = 'https://github.com/imahdimir/td-u-d0-FirmTicker-MonthlySales'
ob = ret_pygithub_repo_obj(rp)
fp = '/Users/mahdi/Downloads/pr.py'
with open(fp , 'rb') as f :
    content = f.read()
ob.create_file('1.py' , 'test commit' , content)

##



"""

    """

import json
from pathlib import Path

import requests

from .consts import Consts


cte = Consts()

def clean_github_url(github_repo_url) :
    inp = github_repo_url

    inp = inp.replace(cte.gi , '')

    spl = inp.split('/' , )
    spl = spl[:2]

    urp = '/'.join(spl)
    urp = urp.split('#')[0]

    url = cte.gi + urp
    return url

def github_url_wt_credentials(user , token , targ_repo) :
    return f'https://{user}:{token}@github.com/{targ_repo}'

def get_usr_tok_fr_json_file(jsp) :
    with open(jsp , 'r') as fi :
        js = json.load(fi)
    return js['usr'] , js['tok']

def get_github_token_json_fp() :
    rsp = requests.get(cte.tr)
    js = rsp.json()
    for fp in js.values() :
        if Path(fp).exists() :
            return fp

def get_token() :
    fp = get_github_token_json_fp()
    if fp :
        _ , tok = get_usr_tok_fr_json_file(fp)
    else :
        tok = input('enter github access token:')
    return tok
